import React, { MouseEvent } from "react";
import { Maximize as MaximizeIcon } from "@carbon/icons-react";
import OverlayTag from "@components/OverlayTag";
import { IImage } from "@interfaces/IImage";

type BaseProps = {
  onClick?: (e: MouseEvent<HTMLDivElement>) => void;
  className?: string;
  faded?: boolean;
  onLoad?: () => void;
  inSlider?: boolean;
};

type ImageProps = IImage & BaseProps;

const Image: React.FC<ImageProps> = ({
  img,
  caption,
  subCaption,
  onFullscreen,
  className,
  tag,
  onClick,
  faded = false,
  onLoad,
  inSlider,
}) => {
  return (
    <figure className={`not-prose ${className || ""}`}>
      <div
        {...(onClick ? { onClick } : {})}
        className={`transition-opacity relative w-fit ${
          faded ? "opacity-60 hover:opacity-80 cursor-pointer" : "opacity-100"
        } ${
          inSlider
            ? "h-[212px] sm:h-[300px] lg:h-[487px]"
            : "max-h-[212px] sm:max-h-[300px] lg:max-h-[487px]"
        }`}
      >
        <img
          onLoad={onLoad}
          className={`rounded-sm h-full ${
            inSlider ? "max-w-none" : "object-cover"
          }`}
          src={img}
          alt={caption}
          title={caption}
        />
        {tag && <OverlayTag text={tag} className="absolute bottom-[5%]" />}
      </div>

      {Boolean(onFullscreen) && (
        <button
          onClick={onFullscreen}
          className="absolute z-10 w-6 h-6 bg-white rounded right-5 bottom-5 flex items-center justify-center"
        >
          <MaximizeIcon />
        </button>
      )}

      {(caption || subCaption) && (
        <figcaption className="inline-block top-full h-max font-inter text-xs leading-5 font-normal">
          <span className="text-grey-900">
            {caption} <span className="text-grey-400">{subCaption}</span>
          </span>
        </figcaption>
      )}
    </figure>
  );
};

export default Image;
