import React from "react";
import { ISocialMediaItem } from "@interfaces/IFooter";
import GitlabLogo from "@assets/images/socialMedia/gitlab.svg";
import GitlabLogoLight from "@assets/images/socialMedia/gitlab_light.svg";
import {
  LogoFacebook,
  LogoMastodon,
  LogoLinkedin,
  LogoTwitter,
  LogoYoutube,
  LogoInstagram,
  LogoGithub,
  LogoXing,
  Home,
  Email,
  CarbonIconType,
} from "@carbon/icons-react";

const socialMediaPropMapping: Record<
  string,
  { icon?: CarbonIconType; title: string }
> = {
  instagram: {
    icon: LogoInstagram,
    title: "Instagram",
  },
  twitter: {
    icon: LogoTwitter,
    title: "Twitter",
  },
  youtube: {
    icon: LogoYoutube,
    title: "YouTube",
  },
  gitlab: {
    title: "GitLab",
  },
  linkedin: {
    icon: LogoLinkedin,
    title: "LinkedIn",
  },
  mastodon: {
    icon: LogoMastodon,
    title: "Mastodon",
  },
  facebook: {
    icon: LogoFacebook,
    title: "Facebook",
  },
  xing: {
    icon: LogoXing,
    title: "Xing",
  },
  github: {
    icon: LogoGithub,
    title: "GitHub",
  },
  website: {
    icon: Home,
    title: "Website",
  },
  email: {
    icon: Email,
    title: "E-Mail",
  },
};

interface SocialMediaProps {
  icons?: ISocialMediaItem[];
  className?: string;
  id?: string;
  light?: boolean;
  grow?: boolean;
}

const SocialMediaIcons: React.FC<SocialMediaProps> = ({
  className,
  icons,
  id,
  light,
  grow,
}) => {
  return (
    <div
      className={`grid gap-4 ${
        grow
          ? "grid-cols-[repeat(auto-fit,minmax(3rem,1fr))] md:grid-cols-[repeat(auto-fit,minmax(2rem,1fr))]"
          : "grid-cols-[repeat(auto-fit,3rem)] md:grid-cols-[repeat(auto-fit,2rem)]"
      } ${className || ""}`}
      id={id}
    >
      {icons?.map((logo, index) => {
        return socialMediaPropMapping?.[logo?.type] ? (
          <div key={index} className="flex items-center justify-center">
            <a
              className={`${
                light ? "bg-white text-grey-900" : "bg-grey-900 text-white"
              } flex items-center justify-center rounded-full aspect-square p-1.5 w-12 md:w-8 h-12 md:h-8`}
              href={`${logo.type === "email" ? "mailto:" : ""}${logo.href}`}
              target="_blank"
              rel="noreferrer"
            >
              <IconComponent type={logo.type} light={light} />
            </a>
          </div>
        ) : null;
      })}
    </div>
  );
};

const IconComponent = ({ type, light }: { type: string; light?: boolean }) => {
  if (type === "gitlab") {
    return (
      <img
        className={`w-full h-full p-0.5`}
        alt={socialMediaPropMapping?.[type]?.title}
        src={light ? GitlabLogo : GitlabLogoLight}
      />
    );
  } else {
    const Component = socialMediaPropMapping?.[type]?.icon || React.Fragment;
    return <Component className="w-full h-full" />;
  }
};

export default SocialMediaIcons;
