import React, { useEffect, useState, Children, isValidElement } from "react";
import Button from "@components/Button";
import { CommonUtils } from "@utils/CommonUtils";
import { Link } from "@components/Link";

interface Props {
  children: React.ReactNode;
  ctaOnClick?: () => unknown;
  ctaCaption?: string;
}

interface IHeadlineProps {
  id: string;
  label: string;
  target: string;
}

export const TableOfContents: React.FC<Props> = ({
  children,
  ctaOnClick,
  ctaCaption,
}) => {
  const [activeHeadline, setActiveHeadline] = useState<string | null>(null);
  const [headlineData, setHeadlineData] = useState<IHeadlineProps[]>([]);
  const headlineClasses =
    "relative overflow-hidden text-sm leading-5 font-medium text-black multi-line-grey-900 group-hover:multi-line-underline cursor-pointer";

  useEffect(() => {
    const data: IHeadlineProps[] = [];
    Children.forEach(children, (child) => {
      if (!isValidElement(child)) return;
      data.push({
        id: CommonUtils.generateID(),
        label: child.props.children,
        target: child.props.target,
      });
    });
    setHeadlineData(data);
    setActiveHeadline(data[0].id);
  }, []);

  return (
    <div className="flex">
      <div className="w-full">
        <ul className="font-inter mb-5">
          {headlineData.map((headline) => (
            <TocItem
              label={headline.label}
              key={headline.id}
              className="block"
              target={headline.target}
              isActive={activeHeadline === headline.id}
              onClick={() => {
                setActiveHeadline(headline.id);
              }}
            />
          ))}
        </ul>
        {ctaCaption && (
          <Button
            text={ctaCaption}
            type="primary"
            size="lg"
            onClick={ctaOnClick}
          />
        )}
      </div>
    </div>
  );
};

interface TocItemProps {
  label: string;
  onClick: () => void;
  isActive: boolean;
  className?: string;
  target: string;
}

export const TocItem: React.FC<TocItemProps> = ({
  label,
  target,
  onClick,
  isActive,
  className = "",
}) => {
  const classes =
    "relative overflow-hidden text-sm leading-5 font-medium text-black multi-line-grey-900 group-hover:multi-line-underline cursor-pointer";
  return (
    <li className="group mb-3">
      <Link onClick={onClick} className={className} to={target}>
        <span
          className={`${classes} ${isActive ? "multi-line-underline" : ""}`}
        >
          {label}
        </span>
      </Link>
    </li>
  );
};

export const Headline: React.FC<{
  target: string;
  children: React.ReactNode;
}> = () => {
  return null;
};
