import * as React from "react";
import Article from "@components/Article";
import { Accordion } from "@components/Accordion";
import { ActionBox } from "@components/ActionBox";
import { Feature } from "@components/Feature";
import { Tabs, Tab } from "@components/Tabs";
import Grid from "@components/Grid";
import Button from "@components/Button";
import { NEWS, TABLE_OF_CONTENTS } from "@common/constants";

const HtmlContent: React.FC = () => {
  return (
    <>
      <h2>File-based routing</h2>
      <p>
        Astro leverages a routing strategy called{" "}
        <strong>file-based routing.</strong> Every <code>.astro</code> file in
        your <code>src/pages</code> directory becomes a page or an endpoint on
        your site based on its file path. Write standard HTML{" "}
        <a href="https://developer.mozilla.org/en-US/docs/Web/HTML/Element/a">
          <code>&lt;a&gt;</code> elements
        </a>{" "}
        in your component template to link between pages.
      </p>
      <blockquote>
        Famous quote goes in here. Lorem ipsum dolor sit amet, consetetur
        sadipscing elitr, sed diam nonumy eirmod tempor invidunt ut labore et
        dolore magna aliquyam erat, sed diam voluptua.
      </blockquote>
      <h3>Page HTML</h3>
      <p>
        Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy
        eirmod tempor invidunt ut labore et dolore magna aliquyam erat, sed diam
        voluptua. At vero eos et accusam et justo duo dolores et ea rebum. Stet
        clita kasd gubergren, no sea takimata sanctus est Lorem ipsum dolor sit
        amet. Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam
        nonumy eirmod tempor invidunt ut labore et dolore magna aliquyam erat,
        sed diam voluptua. At vero eos et accusam et justo duo dolores et ea
        rebum. Stet clita kasd gubergren, no sea takimata sanctus est Lorem
        ipsum dolor sit amet. Lorem ipsum dolor sit amet, consetetur sadipscing
        elitr, sed diam nonumy eirmod tempor invidunt ut labore et dolore magna
        aliquyam erat, sed diam voluptua. At vero eos et accusam et justo duo
        dolores et ea rebum. Stet clita kasd gubergren, no sea takimata sanctus
        est Lorem ipsum dolor sit amet. Here comes a list:
      </p>
      <ul>
        <li>First item</li>
        <li>Second item</li>
        <li>Third item</li>
      </ul>
      <Accordion className="not-prose" title="Closed accordion">
        Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nam egestas sed
        metus nec molestie. Proin mattis ligula vel eros rhoncus, vel dapibus
        est sollicitudin. Phasellus quis velit diam. Suspendisse a aliquet
        velit. Etiam vel accumsan enim. Sed scelerisque leo purus, id luctus
        purus varius a. In hac habitasse platea dictumst. Quisque in lobortis
        tortor. Sed eu pellentesque sem. Duis sagittis leo at nunc condimentum,
        id cursus orci blandit. Maecenas semper urna sit amet viverra interdum.
      </Accordion>
      <Accordion className="not-prose" open title="Opened accordion">
        Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nam egestas sed
        metus nec molestie. Proin mattis ligula vel eros rhoncus, vel dapibus
        est sollicitudin. Phasellus quis velit diam. Suspendisse a aliquet
        velit. Etiam vel accumsan enim. Sed scelerisque leo purus, id luctus
        purus varius a. In hac habitasse platea dictumst. Quisque in lobortis
        tortor. Sed eu pellentesque sem. Duis sagittis leo at nunc condimentum,
        id cursus orci blandit. Maecenas semper urna sit amet viverra interdum.
      </Accordion>
      <p>
        Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy
        eirmod tempor invidunt ut labore et dolore magna aliquyam erat, sed diam
        voluptua. At vero eos et accusam et justo duo dolores et ea rebum. Stet
        clita kasd gubergren, no sea takimata sanctus est Lorem ipsum dolor sit
        amet. Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam
        nonumy eirmod tempor invidunt ut labore et dolore magna aliquyam erat,
        sed diam voluptua. At vero eos et accusam et justo duo dolores et ea
        rebum. Stet clita kasd gubergren, no sea takimata sanctus est Lorem
        ipsum dolor sit amet. Lorem ipsum dolor sit amet, consetetur sadipscing
        elitr, sed diam nonumy eirmod tempor invidunt ut labore et dolore magna
        aliquyam erat, sed diam voluptua. At vero eos et accusam et justo duo
        dolores et ea rebum. Stet clita kasd gubergren, no sea takimata sanctus
        est Lorem ipsum dolor sit amet.
      </p>
      <ActionBox
        className="not-prose"
        title="Fab Friday"
        description="Open knowledge Exchange, weekly from 5–6 pm"
      >
        <Button
          text="Join Fab Friday"
          type="primary"
          onClick={() => console.log("Join Fab Friday")}
        />
        <Button text="Learn more" type="tertiary" href="/" />
      </ActionBox>
      <h3>Leveraging Page Layouts</h3>
      <p>
        Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy
        eirmod tempor invidunt ut labore et dolore magna aliquyam erat, sed diam
        voluptua. At vero eos et accusam et justo duo dolores et ea rebum. Stet
        clita kasd gubergren, no sea takimata sanctus est Lorem ipsum dolor sit
        amet. Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam
        nonumy eirmod tempor invidunt ut labore et dolore magna aliquyam erat,
        sed diam voluptua. At vero eos et accusam et justo duo dolores et ea
        rebum. Stet clita kasd gubergren, no sea takimata sanctus est Lorem
        ipsum dolor sit amet. Lorem ipsum dolor sit amet, consetetur sadipscing
        elitr, sed diam nonumy eirmod tempor invidunt ut labore et dolore magna
        aliquyam erat, sed diam voluptua. At vero eos et accusam et justo duo
        dolores et ea rebum. Stet clita kasd gubergren, no sea takimata sanctus
        est Lorem ipsum dolor sit amet.
      </p>

      <Grid columns={2}>
        <Feature
          className="not-prose"
          title="With Link"
          description="Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nam egestas sed metus nec molestie. Proin mattis ligula vel eros rhoncus, vel dapibus est sollicitudin. Phasellus quis velit diam. Suspendisse a aliquet velit. Etiam vel accumsan enim. Sed scelerisque leo purus, id luctus purus varius a. In hac habitasse platea dictumst. Quisque in lobortis tortor. Sed eu pellentesque sem. Duis sagittis leo at nunc condimentum, id cursus orci blandit. Maecenas semper urna sit amet viverra interdum."
          icon="chat"
          href="http://www.google.de"
        />
        <Feature
          className="not-prose"
          title="Without Link"
          description="Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nam egestas sed metus nec molestie. Proin mattis ligula vel eros rhoncus, vel dapibus est sollicitudin. Phasellus quis velit diam. Suspendisse a aliquet velit. Etiam vel accumsan enim. Sed scelerisque leo purus, id luctus purus varius a. In hac habitasse platea dictumst. Quisque in lobortis tortor. Sed eu pellentesque sem. Duis sagittis leo at nunc condimentum, id cursus orci blandit. Maecenas semper urna sit amet viverra interdum."
          icon="wikis"
        />
      </Grid>

      <h2>Markdown Pages</h2>
      <p>
        Astro also treats any Markdown (<code>.md</code>) files inside of{" "}
        <code>/src/pages/</code> as pages in your final website. These are
        commonly used for text-heavy pages like blog posts and documentation.
      </p>
      <Tabs className="not-prose">
        <Tab label="My account">
          Id orci tellus laoreet id ac. Dolor, aenean leo, ac etiam consequat
          in. Convallis arcu ipsum urna nibh. Pharetra, euismod vitae interdum
          mauris enim, consequat vulputate nibh. Maecenas pellentesque id sed
          tellus mauris, ultrices mauris. Tincidunt enim cursus ridiculus mi.
          Pellentesque nam sed nullam sed diam turpis ipsum eu a sed convallis
          diam.
        </Tab>
        <Tab label="Company">
          Lorem ipsum dolor sit amet, consectetur adipiscing elit. Lorem ipsum
          dolor sit amet, consectetur adipiscing elit. Lorem ipsum dolor sit
          amet, consectetur adipiscing elit.
        </Tab>
        <Tab label="Team Members">
          Lorem ipsum dolor sit amet, consectetur adipiscing elit. Lorem ipsum
          dolor sit amet, consectetur adipiscing elit.
        </Tab>
        <Tab label="Billing">
          Lorem ipsum dolor sit amet, consectetur adipiscing elit. Lorem ipsum
          dolor sit amet, consectetur adipiscing elit. Lorem ipsum dolor sit
          amet, consectetur adipiscing elit.
        </Tab>
      </Tabs>
      <p>
        Page layouts are especially useful for{" "}
        <a href="#markdown-pages">Markdown files.</a> Markdown files can use the
        special <code>layout</code> front matter property to specify a{" "}
        <a href="/en/core-concepts/layouts/">layout component</a> that will wrap
        their Markdown content in a full{" "}
        <code>&lt;html&gt;...&lt;/html&gt;</code> page document.
      </p>

      <Button text={"Just a button"} type={"primary"} size="lg" />

      <h3>H3 Interhead Two Lorem Ipsum</h3>
      <p>
        Duis autem vel eum iriure dolor in hendrerit in vulputate velit esse
        molestie consequat, vel illum dolore eu feugiat nulla facilisis at vero
        eros et accumsan et iusto odio dignissim qui blandit praesent luptatum
        zzril delenit augue duis dolore te feugait nulla facilisi. Lorem ipsum
        dolor sit amet, consectetuer adipiscing elit, sed diam nonummy nibh
        euismod tincidunt ut laoreet dolore magna aliquam erat volutpat. Ut wisi
        enim ad minim veniam, quis nostrud exerci tation ullamcorper suscipit
        lobortis nisl ut aliquip ex ea commodo consequat. Duis autem vel eum
        iriure dolor in hendrerit in vulputate velit esse molestie consequat,
        vel illum dolore eu feugiat nulla facilisis at vero eros et accumsan et
        iusto odio dignissim qui blandit praesent luptatum zzril delenit augue
        duis dolore te feugait nulla facilisi.
      </p>
    </>
  );
};

const BREADCRUMBS = [
  { title: "My Top Page" },
  { title: "Subpage", target: "/home/subpage" },
  { title: "Sub Sub Page", target: "/home/subpage" },
];

const EDIT_TARGET = "/home/subpage";

export const ArticleStory = () => (
  <Article
    teaser={
      "Pages are a special type of Astro component that live in the src/pages/ subdirectory. They are responsible for handling routing, data loading, and overall page layout for every HTML page in your website. This paragraph is a lead paragraph."
    }
    breadcrumbs={BREADCRUMBS}
    editButtonTarget={EDIT_TARGET}
    title="Here comes a very interesting article title"
    subtitle="Hey here goes the subtitle"
    titleImage="https://picsum.photos/id/1026/1600/900"
    tableOfContents={TABLE_OF_CONTENTS}
    relatedContent={NEWS}
    tags={[{ title: "Category 1", target: "#section1" }]}
    dateAndAuthor={"May 13, 2022 | Author Name, Author Name"}
    imageTag="@Copyright"
  >
    <HtmlContent />
  </Article>
);
export default {
  title: "Organisms",
};
ArticleStory.storyName = "Article";
